@@ -73,7 +73,7 @@ go_sys_lib_dir (void)
 }
 
 void
-libgoffice_init (void)
+libgoffice_init ()
 {
 	static gboolean initialized = FALSE;
 
@@ -107,7 +107,7 @@ libgoffice_init (void)
 	/* keep trigger happy linkers from leaving things out */
 	plugin_services_init ();
 	gog_plugin_services_init ();
-#ifdef GOFFICE_HAVE_GTK
+#ifdef GOFFICE_WITH_GTK
 	goc_plugin_services_init ();
 #endif
 	(void) GOG_GRAPH_TYPE;
@@ -137,7 +137,7 @@ libgoffice_shutdown (void)
 {
 	gog_themes_shutdown ();
 	go_fonts_shutdown ();
-#ifdef GOFFICE_HAVE_GTK
+#ifdef GOFFICE_WITH_GTK
 	goc_plugin_services_shutdown ();
 #endif
 	gog_plugin_services_shutdown ();
