@@ -29,7 +29,7 @@
 #include "gog-renderer.h"
 #include <goffice/data/go-data-impl.h>
 #include <goffice/data/go-data.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/math/go-math.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -41,8 +41,9 @@ typedef GObjectClass GogErrorBarClass;
 static GObjectClass *error_bar_parent_klass;
 
 #ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/go-color-selector.h>
 #include <goffice/gtk/goffice-gtk.h>
+#include <goffice/gtk/go-pixbuf.h>
+#include <goffice/gtk/go-color-selector.h>
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkcellrendererpixbuf.h>
@@ -502,27 +503,31 @@ gog_error_bar_get_bounds (GogErrorBar const *bar, int index, double *min, double
 {
 	double value;
 	GOData *data;
+	GODataVector *vec;
 	int length;
-	
+
 	/* -1 ensures that the bar will not be displayed if the error is not a correct one.
 		With a 0 value, it might be, because of rounding errors */
-	*min = *max = -1.; 
+	*min = *max = -1.;
 
 	g_return_val_if_fail (IS_GOG_ERROR_BAR (bar), FALSE);
 	if (!gog_series_is_valid (bar->series))
 		return FALSE;
-	value = go_data_vector_get_value (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data), index);
+	vec = GO_DATA_VECTOR (bar->series->values[bar->dim_i].data);
+	if (vec == NULL)
+		return FALSE;
+	value = go_data_vector_get_value (vec, index);
 	data = bar->series->values[bar->error_i].data;
 	length = (IS_GO_DATA (data)) ? go_data_vector_get_len (GO_DATA_VECTOR (data)) : 0;
-	
+
 	if ((bar->type == GOG_ERROR_BAR_TYPE_NONE) || isnan (value) || !go_finite (value))
 		return FALSE;
-	
-	if (length == 1) 
+
+	if (length == 1)
 		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
 	else if (length > index)
 		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
-	
+
 	data = bar->series->values[bar->error_i + 1].data;
 	length = (IS_GO_DATA (data))? go_data_vector_get_len (GO_DATA_VECTOR (data)): 0;
 	if (length == 0)
@@ -531,14 +536,14 @@ gog_error_bar_get_bounds (GogErrorBar const *bar, int index, double *min, double
 		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
 	else if (length > index)
 		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
-	
+
 	if (isnan (*min) || !go_finite (*min) || (*min <= 0)) {
 		*min = -1.;
 	}
 	if (isnan (*max) || !go_finite (*max) || (*max <= 0)) {
 		*max = -1.;
 	}
-	
+
 	switch (bar->type)
 	{
 	case GOG_ERROR_BAR_TYPE_RELATIVE:
@@ -571,6 +576,8 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 	}
 
 	imax = go_data_vector_get_len (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
+	if (imax == 0)
+		return;
 	go_data_vector_get_minmax (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data), min, max);
 	values = go_data_vector_get_values (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
 
